@@ -1,29 +1,26 @@
+#!/usr/bin/env bash
 #Berrie is a 32-bit Rasberry Pi managed by Bruce Rindahl
 #This is script to launch custom compiled PostgreSQL
 #export label=berrie #this is passed in via Jenkins
-export WORKSPACE=/home/jenkins/workspace
-
-
-
-export OS_BUILD=32
-export PG_VER=12
-export PGPATH=${WORKSPACE}/pg/label/${label}/rel/pg${PG_VER}w${OS_BUILD}
-export PATH=${PATH}:${PGPATH}/bin:${PGPATH}/lib
-export PGPORT=55432
-export PGDATA=$PGPATH/data_${PGPORT}
+SCRIPT=$(readlink -f "$0")
+export CUR_DIR=$(dirname "$SCRIPT")
+echo $CUR_DIR
+export CONFIG_FILE="$CUR_DIR/configs.sh"
+. $CONFIG_FILE
+echo $PATH
 export PGLOG="$PGDATA/pgsql.log"
 # What to use to start up the postmaster
-DAEMON="$PGPATH/bin/pg_ctl -D $PGDATA -l logfile start"
+DAEMON="$PGPATH/bin/pg_ctl -D $PGDATA -o '-F' -l logfile start"
 
 # What to use to shut down the postmaster
 PGCTL="$PGPATH/bin/pg_ctl"
 
 # remove cluster if exists
 if [ -d $PGDATA ] ; then
-    if [ -d $PGDATA/postmaster.pid] ; then
+    if [ -d $PGDATA/postmaster.pid ] ; then
     	$PGCTL stop -D $PGDATA -s -m fast
     fi;
-	
+
     rm -rf $PGDATA
 fi;
 
@@ -35,4 +32,4 @@ $DAEMON &
 #sleep a bit because sometimes postgres takes a bit to start up
 sleep 20
 echo "ok"
-exit 0
\ No newline at end of file
+exit 0
