@@ -4,21 +4,18 @@
 #export BRANCH=618a67b1d6fc223dd5a4c0b02c824939f21dbd65
 ## label is set by jenkins
 #export label=${label}
-
-export WORKSPACE=/home/jenkins/workspace
-
-cd ${WORKSPACE}/PostGIS_Worker_Run/label/${label}/$BRANCH
-export OS_BUILD=32
-export PG_VER=12
-export PGPATH=${WORKSPACE}/pg/label/${label}/rel/pg${PG_VER}w${OS_BUILD}
-
-export PATH=${PGPATH}/bin:${PGPATH}/lib:${PATH}
-export PGPORT=55432
-export PGDATA=$PGPATH/data_${PGPORT}
-export PGHOST=localhost
+SCRIPT=$(readlink -f "$0")
+export CUR_DIR=$(dirname "$SCRIPT")
+echo $CUR_DIR
+export CONFIG_FILE="$CUR_DIR/configs.sh"
+. $CONFIG_FILE
+echo $PATH
+echo $WORKSPACE
 
 sh autogen.sh
-./configure --with-pgconfig=${PGPATH}/bin/pg_config --without-protobuf
+./configure --with-pgconfig=${PGPATH}/bin/pg_config \
+  --with-geosconfig=${GEOS_PATH}/bin/geos-config \
+	--without-protobuf
 #make clean
 make
 export err_status=0
@@ -27,6 +24,9 @@ make install
 make check RUNTESTFLAGS="-v --extension"
 err_status=$?
 
+make garden
+err_status=$?
+
 if [ -d $PGDATA/postmaster.pid ] ; then
 	$PGCTL stop -D $PGDATA -s -m fast
 fi
