@@ -14,19 +14,20 @@
 #export GCC_TYPE=
 #if no override is set - use these values
 #otherwise use the ones jenkins passes thru
-#!/bin/bash
+#!/usr/bin/env bash
 if  [[ "${OVERRIDE}" == '' ]] ; then
-	export GEOS_VER=3.8.1
-	export GDAL_VER=2.4.4
-	export PROJ_VER=5.2.0
-	export SFCGAL_VER=1.3.8
-	export CGAL_VER=5.0
-	export ICON_VER=1.15
+	export GEOS_VER=3.10.0
+	export GDAL_VER=3.3.3
+	export PROJ_VER=7.2.1
+	export SFCGAL_VER=1.4.0
+	export CGAL_VER=5.3
+	export ICON_VER=1.16
 	export ZLIB_VER=1.2.11
   export PROTOBUF_VER=3.2.0
 	export PROTOBUFC_VER=1.2.1
 	export JSON_VER=0.12
-	export PROJSO=libproj-13.dll
+	export PROJSO=libproj-19.dll
+	export CURL_VER=7.73
 fi;
 
 export PROTOBUF_VER=3.2.0
@@ -40,6 +41,12 @@ fi;
 
 echo "ICON_VER ${ICON_VER}"
 
+if  [[ "${CURL_VER}" == '' ]] ; then
+  export CURL_VER=7.73
+fi;
+
+echo "CURL_VER ${CURL_VER}"
+
 #set to something even if override is on but not set
 if  [[ "${ZLIB_VER}" == '' ]] ; then
   export ZLIB_VER=1.2.11
@@ -53,7 +60,7 @@ fi;
 
 #set to something even if override is on but not set
 if  [[ "${CGAL_VER}" == '' ]] ; then
-  export CGAL_VER=4.11
+  export CGAL_VER=5.3
 fi;
 
 echo "ZLIB_VER $ZLIB_VER"
@@ -61,6 +68,7 @@ echo "PROJ_VER $PROJ_VER"
 echo "LIBXML_VER $LIBXML_VER"
 echo "CGAL_VER $CGAL_VER"
 
+
 export PROJECTS=/projects
 export PROJECTS=/projects
 export PATHOLD=$PATH
@@ -74,33 +82,21 @@ export PATHOLD=$PATH
 WEB=/home/www/postgis/htdocs
 DWN=${WEB}/download
 
-export PATHOLD="/mingw/bin:/mingw/include:/c/Windows/system32:/c/Windows:.:/bin:/include:/usr/local/bin:/c/ming${OS_BUILD}}${GCC_TYPE}/svn"
+export PATHOLD="/mingw/bin:/mingw/include:/c/Windows/system32:/c/Windows:.:/bin:/include:/usr/local/bin"
 #export PG_VER=9.2beta2
 
 echo PATH BEFORE: $PATH
 
 export PGPATH=${PROJECTS}/postgresql/rel/pg${PG_VER}w${OS_BUILD}${GCC_TYPE}
 export PGPATHEDB=${PGPATH}edb
-export PROJSO=libproj-9.dll
+#export PROJSO=libproj-13.dll
 export POSTGIS_MINOR_VER=${POSTGIS_MAJOR_VERSION}.${POSTGIS_MINOR_VERSION}
 export POSTGIS_MICRO_VER=${POSTGIS_MAJOR_VERSION}.${POSTGIS_MINOR_VERSION}.${POSTGIS_MICRO_VERSION}
 
-if [[ "$POSTGIS_MICRO_VERSION"  == *SVN* || "$POSTGIS_MICRO_VERSION"  == *dev* ]] ; then
-	export POSTGIS_SRC=${PROJECTS}/postgis/branches/${POSTGIS_MINOR_VER}
-	export svnurl="https://svn.osgeo.org/postgis/branches/${POSTGIS_MINOR_VER}"
-else
-	#tagged version -- official release
-	export POSTGIS_SRC=${PROJECTS}/postgis/tags/${POSTGIS_MINOR_VER}.${POSTGIS_MICRO_VERSION}
-	export svnurl="https://svn.osgeo.org/postgis/tags/${POSTGIS_MINOR_VER}.${POSTGIS_MICRO_VERSION}"
-fi;
-
 if [ -n "$SOURCE_FOLDER" ]; then
   export POSTGIS_SRC=${PROJECTS}/postgis/$SOURCE_FOLDER
 fi
 
-if [[ "$reference"  == *trunk* ]] ; then
-	export svnurl="https://svn.osgeo.org/postgis/trunk"
-fi;
 #export POSTGIS_SRC=${PROJECTS}/postgis/trunk
 #POSTGIS_SVN_REVISION=will_be_passed_in_by_bot
 export GDAL_DATA="${PROJECTS}/gdal/rel-${GDAL_VER}w${OS_BUILD}${GCC_TYPE}/share/gdal"
@@ -118,7 +114,6 @@ export PCRE_VER=8.33
 outdir="${RELDIR}/${RELVERDIR}"
 package="${RELDIR}/${RELVERDIR}.zip"
 verfile="${RELDIR}/${RELVERDIR}/version.txt"
-#svnurl="http://svn.osgeo.org/postgis/trunk"
 rm -rf $outdir
 rm $package
 mkdir -p $outdir
@@ -203,25 +198,24 @@ fi;
 
 echo "PROTOBUF VERSION: ${PROTOBUF_VER} https://github.com/google/protobuf" >> $verfile
 echo "PROTOBUF-C VERSION: ${PROTOBUFC_VER} https://github.com/protobuf-c/protobuf-c"  >> $verfile
+echo "CURL VERSION: ${CURL_VER} https://github.com/protobuf-c/protobuf-c"  >> $verfile
 cp ${PROJECTS}/libxml/rel-libxml2-${LIBXML_VER}w${OS_BUILD}${GCC_TYPE}/bin/*.dll  $outdir/bin/
 #cp ${PGPATHEDB}/bin/libxml2-2.dll   $outdir/bin/
 
 cd ${POSTGIS_SRC}
 strip postgis/*.dll
+strip sfcgal/*.dll
 strip raster/rt_pg/*.dll
 strip liblwgeom/.libs/*.dll
 
 cp postgis/*.dll ${RELDIR}/${RELVERDIR}/lib
+cp sfcgal/*.dll ${RELDIR}/${RELVERDIR}/lib
 cp topology/*.dll ${RELDIR}/${RELVERDIR}/lib
 cp raster/rt_pg/*.dll ${RELDIR}/${RELVERDIR}/lib
 cp doc/*_comments.sql ${RELDIR}/${RELVERDIR}/share/contrib/postgis-${POSTGIS_MINOR_VER}
 cp postgis/*.sql ${RELDIR}/${RELVERDIR}/share/contrib/postgis-${POSTGIS_MINOR_VER}
 cp raster/rt_pg/*.sql ${RELDIR}/${RELVERDIR}/share/contrib/postgis-${POSTGIS_MINOR_VER}
 cp utils/*.pl ${RELDIR}/${RELVERDIR}/utils
-#add extras
-#svn export "${svnurl}/extras" ${RELDIR}/${RELVERDIR}/share/contrib/postgis-${POSTGIS_MINOR_VER}/extras
-#cp raster/rt_pg/rtpostgis.sql ${RELDIR}/${RELVERDIR}/share/contrib/postgis-${POSTGIS_MINOR_VER}
-#cp raster/rt_pg/rtpostgis_upgrade_20_minor.sql ${RELDIR}/${RELVERDIR}/share/contrib/postgis-${POSTGIS_MINOR_VER}
 
 cp raster/loader/.libs/raster2pgsql.exe ${RELDIR}/${RELVERDIR}/bin
 cp raster/loader/raster2pgsql.exe ${RELDIR}/${RELVERDIR}/bin
@@ -257,6 +251,8 @@ echo "GEOS VERSION: ${GEOS_VER} https://trac.osgeo.org/geos" >> $verfile
 echo "GDAL VERSION: ${GDAL_VER} https://gdal.org/download.html#current-releases" >> $verfile
 echo "PROJ VERSION: ${PROJ_VER} https://proj.org/download.html#current-release" >> $verfile
 
+echo "LIBICONV VERSION: ${ICON_VER} http://ftp.gnu.org/gnu/libiconv/libiconv-${ICONV_VER}.tar.gz" >> $verfile
+
 if [ -n "$SFCGAL_VER"  ]; then
     echo "CGAL VERSION: ${CGAL_VER} http://www.cgal.org" >> $verfile
     echo "BOOST VERSION: ${BOOST_VER} http://www.boost.org" >> $verfile
@@ -266,7 +262,6 @@ fi;
 if [ -f ${PROJECTS}/gdal/rel-${GDAL_VER}w${OS_BUILD}${GCC_TYPE}/gdal_depends.txt ]; then
 	cat $verfile ${PROJECTS}/gdal/rel-${GDAL_VER}w${OS_BUILD}${GCC_TYPE}/gdal_depends.txt > $verfile
 fi
-
 #echo "PAGC ADDRESS STANDARDIZER: http://sourceforge.net/p/pagc/code/HEAD/tree/branches/sew-refactor/postgresql " >> $verfile
 cd ${RELDIR}
 zip -r $package ${RELVERDIR}
