@@ -15,7 +15,7 @@ BEGIN
 		$unpackage$;
 
 		RAISE WARNING 'PostGIS Raster functionality has been unpackaged'
-		USING HINT = 'type `SELECT postgis_extensions_upgrade(); to finish the upgrade.'
+		USING HINT = 'type `SELECT postgis_extensions_upgrade();` to finish the upgrade.'
 						' After upgrading, if you want to drop raster, run: DROP EXTENSION postgis_raster;';
 	END IF;
 END
