@@ -1537,12 +1537,16 @@ compute_gserialized_stats_mode(VacAttrStats *stats, AnalyzeAttrFetchFunc fetchfu
 	/* If there's no useful features, we can't work out stats */
 	if ( ! notnull_cnt )
 	{
+#if POSTGIS_DEBUG_LEVEL > 0
 		Oid relation_oid = stats->attr->attrelid;
 		char *relation_name = get_rel_name(relation_oid);
-		elog(NOTICE,
-		     "PostGIS: Unable to compute statistics for \"%s.%s\": No non-null/empty features",
+		char *namespace = get_namespace_name(get_rel_namespace(relation_oid));
+		elog(DEBUG1,
+		     "PostGIS: Unable to compute statistics for \"%s.%s.%s\": No non-null/empty features",
+		     namespace ? namespace : "(NULL)",
 		     relation_name ? relation_name : "(NULL)",
 		     stats->attr->attname.data);
+#endif /* POSTGIS_DEBUG_LEVEL > 0 */
 		stats->stats_valid = false;
 		return;
 	}
@@ -2240,6 +2244,7 @@ gserialized_sel_internal(PlannerInfo *root, List *args, int varRelid, int mode)
 
 	GBOX search_box;
 	float8 selectivity = 0;
+	Const *otherConst;
 
 	POSTGIS_DEBUGF(2, "%s: entered function", __func__);
 
@@ -2256,7 +2261,15 @@ gserialized_sel_internal(PlannerInfo *root, List *args, int varRelid, int mode)
 		return DEFAULT_ND_SEL;
 	}
 
-	if (!gserialized_datum_get_gbox_p(((Const*)other)->constvalue, &search_box))
+	otherConst = (Const*)other;
+	if ((!otherConst) || otherConst->constisnull)
+	{
+		ReleaseVariableStats(vardata);
+		POSTGIS_DEBUGF(2, "%s: constant argument is NULL", __func__);
+		return DEFAULT_ND_SEL;
+	}
+
+	if (!gserialized_datum_get_gbox_p(otherConst->constvalue, &search_box))
 	{
 		ReleaseVariableStats(vardata);
 		POSTGIS_DEBUGF(2, "%s: search box is EMPTY", __func__);
@@ -2310,7 +2323,7 @@ Datum gserialized_estimated_extent(PG_FUNCTION_ARGS)
 	int key_type;
 
 	/* We need to initialize the internal cache to access it later via postgis_oid() */
-	postgis_initialize_cache(fcinfo);
+	postgis_initialize_cache();
 
 	if ( PG_NARGS() == 4 )
 	{
@@ -2576,8 +2589,11 @@ Datum _postgis_gserialized_index_extent(PG_FUNCTION_ARGS)
 	text *col = PG_GETARG_TEXT_P(1);
 	Oid idx_oid;
 
+	if(!tbl_oid)
+		PG_RETURN_NULL();
+
 	/* We need to initialize the internal cache to access it later via postgis_oid() */
-	postgis_initialize_cache(fcinfo);
+	postgis_initialize_cache();
 
 	idx_oid = table_get_spatial_index(tbl_oid, col, &key_type);
 	if (!idx_oid)
