@@ -94,7 +94,7 @@ ST_AsGeoJsonRow(PG_FUNCTION_ARGS)
 	Oid geog_oid = InvalidOid;
 
 	/* We need to initialize the internal cache to access it later via postgis_oid() */
-	postgis_initialize_cache(fcinfo);
+	postgis_initialize_cache();
 	geom_oid = postgis_oid(GEOMETRYOID);
 	geog_oid = postgis_oid(GEOGRAPHYOID);
 
